@@ -3,7 +3,9 @@ from nonebot import get_driver, on_regex
 
 from .config import Config
 from nonebot.typing import T_State
-from nonebot.adapters import Bot, Event, Message
+from pathlib import Path
+from nonebot.adapters.onebot.v11 import Bot, Event,Message
+from nonebot.params import T_State,State
 
 global_config = get_driver().config
 config = Config(**global_config.dict())
@@ -19,9 +21,9 @@ import re
 #     pass
 biliav = on_regex("av(\d{1,12})|BV(1[A-Za-z0-9]{2}4.1.7[A-Za-z0-9]{2})")
 @biliav.handle()
-async def handle(bot:Bot,event:Event,state:T_State):
+async def handle(bot:Bot,event:Event,state:T_State=State()):
     avcode = re.search('av(\d{1,12})|BV(1[A-Za-z0-9]{2}4.1.7[A-Za-z0-9]{2})', str(event.get_message()))
     if avcode==None:
         return
     rj = await get_av_data(avcode[0])
-    await biliav.send(rj)
+    await bot.send(event=event,message=rj)
